==> libcobra-java_0.97.4.orig.tar.gz: libcobra-java-0.97.4.orig/src/org/w3c/dom/html2/HTMLTableColElement.java <==
/*
    GNU LESSER GENERAL PUBLIC LICENSE
    Copyright (C) 2006 The Lobo Project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Contact info: xamjadmin@users.sourceforge.net
*/
/*
 * Copyright (c) 2003 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.html2;

/**
 * Regroups the <code>COL</code> and <code>COLGROUP</code> elements. See the 
 * COL element definition in HTML 4.01.
 * <p>See also the <a href='http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109'>Document Object Model (DOM) Level 2 HTML Specification</a>.
 */
public interface HTMLTableColElement extends HTMLElement {
    /**
     * Horizontal alignment of cell data in column. See the align attribute 
     * definition in HTML 4.01.
     */
    public String getAlign();
    /**
     * Horizontal alignment of cell data in column. See the align attribute 
     * definition in HTML 4.01.
     */
    public void setAlign(String align);

    /**
     * Alignment character for cells in a column. See the char attribute 
     * definition in HTML 4.01.
     */
    public String getCh();
    /**
     * Alignment character for cells in a column. See the char attribute 
     * definition in HTML 4.01.
     */
    public void setCh(String ch);

    /**
     * Offset of alignment character. See the charoff attribute definition in 
     * HTML 4.01.
     */
    public String getChOff();
    /**
     * Offset of alignment character. See the charoff attribute definition in 
     * HTML 4.01.
     */
    public void setChOff(String chOff);

    /**
     * Indicates the number of columns in a group or affected by a grouping. 
     * See the span attribute definition in HTML 4.01.
     */
    public int getSpan();
    /**
     * Indicates the number of columns in a group or affected by a grouping. 
     * See the span attribute definition in HTML 4.01.
     */
    public void setSpan(int span);

    /**
     * Vertical alignment of cell data in column. See the valign attribute 
     * definition in HTML 4.01.
     */
    public String getVAlign();
    /**
     * Vertical alignment of cell data in column. See the valign attribute 
     * definition in HTML 4.01.
     */
    public void setVAlign(String vAlign);

    /**
     * Default column width. See the width attribute definition in HTML 4.01.
     */
    public String getWidth();
    /**
     * Default column width. See the width attribute definition in HTML 4.01.
     */
    public void setWidth(String width);

}

==> libcobra-java_0.98.4.orig.tar.gz: libcobra-java-0.98.4.orig/src/org/w3c/dom/html2/HTMLTableColElement.java <==
/*
    GNU LESSER GENERAL PUBLIC LICENSE
    Copyright (C) 2006 The Lobo Project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Contact info: lobochief@users.sourceforge.net
*/
/*
 * Copyright (c) 2003 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.html2;

/**
 * Regroups the <code>COL</code> and <code>COLGROUP</code> elements. See the 
 * COL element definition in HTML 4.01.
 * <p>See also the <a href='http://www.w3.org/TR/2003/REC-DOM-Level-2-HTML-20030109'>Document Object Model (DOM) Level 2 HTML Specification</a>.
 */
public interface HTMLTableColElement extends HTMLElement {
    /**
     * Horizontal alignment of cell data in column. See the align attribute 
     * definition in HTML 4.01.
     */
    public String getAlign();
    /**
     * Horizontal alignment of cell data in column. See the align attribute 
     * definition in HTML 4.01.
     */
    public void setAlign(String align);

    /**
     * Alignment character for cells in a column. See the char attribute 
     * definition in HTML 4.01.
     */
    public String getCh();
    /**
     * Alignment character for cells in a column. See the char attribute 
     * definition in HTML 4.01.
     */
    public void setCh(String ch);

    /**
     * Offset of alignment character. See the charoff attribute definition in 
     * HTML 4.01.
     */
    public String getChOff();
    /**
     * Offset of alignment character. See the charoff attribute definition in 
     * HTML 4.01.
     */
    public void setChOff(String chOff);

    /**
     * Indicates the number of columns in a group or affected by a grouping. 
     * See the span attribute definition in HTML 4.01.
     */
    public int getSpan();
    /**
     * Indicates the number of columns in a group or affected by a grouping. 
     * See the span attribute definition in HTML 4.01.
     */
    public void setSpan(int span);

    /**
     * Vertical alignment of cell data in column. See the valign attribute 
     * definition in HTML 4.01.
     */
    public String getVAlign();
    /**
     * Vertical alignment of cell data in column. See the valign attribute 
     * definition in HTML 4.01.
     */
    public void setVAlign(String vAlign);

    /**
     * Default column width. See the width attribute definition in HTML 4.01.
     */
    public String getWidth();
    /**
     * Default column width. See the width attribute definition in HTML 4.01.
     */
    public void setWidth(String width);

}
